var Report = function()
{
	var report = {};
	var debug = 0;
	
	// Page initialization
	report.initPage = function()
	{
		
		// Step 1
		Buttons.addClickHandler('btnSelectRawBioAssays', report.selectRawBioAssays);
		Events.addEventHandler('reportSoftware', 'change', report.softwareOnChange);
		Events.addEventHandler('rawBioAssays', 'base-selected', report.setRawBioAssayCallback);
		Events.addEventHandler('step-1', 'wizard-validate', report.validateStep1);

		// Navigation
		Buttons.addClickHandler('gocancel', Wizard.cancelWizard);
		Buttons.addClickHandler('gorestart', Wizard.restartWizard);
		Buttons.addClickHandler('gonext', Wizard.goNextOnClick);
		Buttons.addClickHandler('goregister', Wizard.goRegister);
			
		// Final registration
		Events.addEventHandler('wizard', 'wizard-submit', report.submit);

		Reggie.loadSoftware('REPORT_SOFTWARE', 'reportSoftware', 'REPORT_TEMPLATE,PARAMETER_SET', Data.get('page-data', 'report'));
		
		Wizard.showLoadingAnimation('Loading bioassays...');
		var url = '../Report.servlet?ID='+App.getSessionId();
		url += '&cmd=GetRawBioAssayWithoutReport';
		url += '&report='+encodeURIComponent(Data.get('page-data', 'report'));
		Wizard.asyncJsonRequest(url, report.initializeStep1);
	}
	
	// --- Step 1 -----------------------------------
	report.initializeStep1 = function(response)
	{
		var frm = document.forms['reggie'];
		
		Doc.element('reportName').innerHTML = Strings.encodeTags(response.reportName);
		Doc.element('configSection').innerHTML = Strings.encodeTags(response.configSection);
		
		var rawBioAssays = response.rawBioAssays;
		if (rawBioAssays.length > 0)
		{
			var firstPlate = null;
			for (var rawNo=0; rawNo < rawBioAssays.length; rawNo++)
			{
				var raw = rawBioAssays[rawNo];
				var lib = raw.lib;
				var libPlate = lib.bioWell ? lib.bioWell.bioPlate : null;
				if (firstPlate == null && libPlate != null) firstPlate = libPlate.name;
				
				var name = (rawNo+1) + ': ';
				if (libPlate) name += libPlate.name + ' - ';
				name += raw.name;
				if (raw.AutoProcess == 'ReProcess')
				{
					name += ' [R]';
				}
				
				var option = new Option(name, raw.id, false, libPlate != null && libPlate.name==firstPlate);
				option.rawBioAssay = raw;
				frm.rawBioAssays.options[frm.rawBioAssays.length] = option;
			}
		}
		else
		{
			Wizard.setInputStatus('rawBioAssays', 'invalid', 'No raw bioassays available for processing');
		}

		Doc.show('step-1');
		Doc.show('goregister');
	}
	
	report.selectRawBioAssays = function()
	{
		var frm = document.forms['reggie'];
		if (frm.rawBioAssays.disabled) return;
		var url = '&resetTemporary=1';
		url += '&tmpfilter:STRING:rawDataType=cufflinks';
		url += '&tmpfilter:INT:spots='+encodeURIComponent('>0');
		Dialogs.selectItem('RAWBIOASSAY', 'rawBioAssays', 1, url);
	}

	report.setRawBioAssayCallback = function(event)
	{
		var raw = event.detail;
		
		var frm = document.forms['reggie'];
		var rawBioAssays = frm.rawBioAssays;
		for (var i = 0; i < rawBioAssays.length; i++)
		{
			if (rawBioAssays[i].value == raw.id)
			{
				rawBioAssays[i].selected = true;
				Wizard.setInputStatus('rawBioAssays');
				return;
			}
		}

		var option = new Option(raw.name, raw.id);
		option.rawBioAssay = raw;
		option.selected = true;
		rawBioAssays[rawBioAssays.length] = option;
		Wizard.setInputStatus('rawBioAssays');
	}

	
	report.softwareOnChange = function(event)
	{
		var frm = document.forms['reggie'];
		var target = event.currentTarget;
		var item = target[target.selectedIndex].item;
		if (!item) item = {};
		
		Doc.element(target.id+'.parameterSet').innerHTML = Strings.encodeTags(item.ParameterSet || 'default');
		Doc.element(target.id+'.description').innerHTML = Strings.encodeTags(item.description);
		Wizard.setInputStatus(target.id, 'valid');

		if (item.ParameterSet)
		{
			var url = '../Install.servlet?ID='+App.getSessionId();
			url += '&cmd=GetParameterSetInfo';
			url += '&parameterSet='+encodeURIComponent(item.ParameterSet);
			url += '&targetId='+target.id;
			Wizard.asyncJsonRequest(url, report.parameterSetInfoLoaded);
		}
	}

	report.parameterSetInfoLoaded = function(response)
	{
		if (!response.parameters || response.parameters.length == 0)
		{
			Wizard.setInputStatus(response.targetId, 'warning', 'Can\'t find \'' + Strings.encodeTags(response.parameterSet) + '\' parameter set in reggie-config.xml');
		}
	}

	
	report.submit = function()
	{
		var frm = document.forms['reggie'];
		var submitInfo = {};
		
		var rawBioAssays = [];
		submitInfo.rawBioAssays = rawBioAssays;
		submitInfo.software = parseInt(frm.reportSoftware.value);
		submitInfo.report = Data.get('page-data', 'report');
			
		for (var rawNo = 0; rawNo < frm.rawBioAssays.length; rawNo++)
		{
			if (frm.rawBioAssays[rawNo].selected) 
			{
				var raw = {};
				raw.id = frm.rawBioAssays[rawNo].rawBioAssay.id;
				rawBioAssays[rawBioAssays.length] = raw;
			}
		}

		var url = '../Report.servlet?ID='+App.getSessionId();
		url += '&cmd=CreateReport';
		Wizard.showLoadingAnimation('Performing registration...');
		Wizard.asyncJsonRequest(url, report.submissionResults, 'POST', JSON.stringify(submitInfo));
	}
	
	report.submissionResults = function(response)
	{
		Wizard.showFinalMessage(response.messages);
		Doc.show('gorestart');
	}
	
	
	return report;
}();

Doc.onLoad(Report.initPage);

