var Protocol = function()
{
	var protocol = {};
	var debug = 0;
	
	var LOW_QUANTITY_WARNING_FACTOR = 2;

	// Page initialization
	protocol.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'protocol')
		{
			Buttons.addClickHandler('print-button', Wizard.goPrint);	

			var mrnaPlateId = Data.int('page-data', 'mrna-plate');

			var url = '../MRna.servlet?ID='+App.getSessionId();
			url += '&cmd=GetMRnaInfoForPlate&bioplate='+mrnaPlateId;		
			Wizard.showLoadingAnimation('Loading mRNA bioplate information...');
			Wizard.asyncJsonRequest(url, protocol.initializeProtocol);
		}
		else
		{
			Events.addEventHandler('bioplate', 'change', protocol.bioplateOnChange);
			Events.addEventHandler('listview', 'click', protocol.viewProtocol);
			Events.addEventHandler('plateview', 'click', protocol.viewProtocol);
			Events.addEventHandler('stratageneConc', 'keypress', Events.numberOnly);

			var url = '../MRna.servlet?ID='+App.getSessionId();
			url += '&cmd=GetUnprocessedPlates&plateType=MRNA';
			Wizard.showLoadingAnimation('Loading mRNA plates...');
			Wizard.asyncJsonRequest(url, protocol.initializeStep1);
		}
	}


	protocol.initializeStep1 = function(response)
	{
		var frm = document.forms['reggie'];	

		var bioplates = response.bioplates;
		var plates = frm.bioplate;
		if (bioplates.length > 0)
		{
			for (var i=0; i < bioplates.length; i++)
			{
				var bioplate = bioplates[i];
				var name = bioplate.name;
				if (bioplate.AutoProcessing == 'PreNormalizeRNA')
				{
					name += ' (pre-normalized)';
				}
				else if (bioplate.DilutionDate)
				{
					name += ' (diluted ' + Reggie.reformatDate(bioplate.DilutionDate) + ')';
				}
				var option = new Option(name, bioplate.id);
				option.bioplate = bioplate;
				plates.options[plates.length] = option;
			}
			bioplateIsValid = true;
			
			protocol.bioplateOnChange();
			protocol.loadStratageneConc();
		}
		else
		{
			Wizard.setFatalError('No mRNA bioplates available for processing.');
			return;
		}

		Doc.show('step-1');
		Doc.show('gonext');
	}
	
	
	// Add pools to the pools list based on the bioplate selection
	protocol.bioplateOnChange = function()
	{
		var frm = document.forms['reggie'];
		var bioplate = frm.bioplate[frm.bioplate.selectedIndex].bioplate;
		Doc.element('comments').innerHTML = Strings.encodeTags(bioplate.comments);
		frm.poolSchema.value = bioplate.poolSchema;
	}
	
	protocol.saveStratageneConc = function()
	{
		if (!window.localStorage) return;
		
		var frm = document.forms['reggie'];	
		var stratageneInfo = new Object();
		stratageneInfo.conc = frm.stratageneConc.value;
		window.localStorage.setItem('reggie.stratagene-info', JSON.stringify(stratageneInfo));
	}

	protocol.loadStratageneConc = function()
	{
		if (!window.localStorage) return;
		var frm = document.forms['reggie'];	
		
		var stratageneInfo = JSON.parse(window.localStorage.getItem('reggie.stratagene-info'));
		if (stratageneInfo)
		{
			frm.stratageneConc.value = stratageneInfo.conc;
		}
	}

	protocol.viewProtocol = function(event)
	{
		protocol.saveStratageneConc();
		
		var frm = document.forms['reggie'];
		if (frm.bioplate && !frm.bioplate.disabled)
		{
			frm.view.value = Data.get(event.currentTarget, 'protocol-type');
			frm.submit();
		}
	}

	
	protocol.initializeProtocol = function(response)
	{
		var plate = response.plate;
		if (plate.DilutionDate)
		{
			Doc.element('dilution-date').innerHTML = Reggie.reformatDate(plate.DilutionDate);
			Doc.element('dilution-operator').innerHTML = Strings.encodeTags(plate.DilutionOperator);
		}
		
		var list = response.mrna;
		var stratageneConc = Data.float('page-data', 'stratagene-conc');
		
		// Pre-process the return mRNA items
		var allPreNormalized = true;
		for (var i = 0; i < list.length; i++)
		{
			allPreNormalized &= list[i].rna.preNormalized;
			protocol.checkAndPreProcessMRna(list[i], stratageneConc);
		}
		
		var view = Data.get('page-data', 'view');
		if (view == 'list')
		{
			protocol.viewAsList(list);
		}
		else
		{
			protocol.viewAsPlate(plate, list)
		}
		if (allPreNormalized)
		{
			Doc.element('dilution-date').innerHTML = 'PreNormalized';
		}
	}
	
	protocol.checkAndPreProcessMRna = function(mrna, stratageneConc)
	{
		var rna = mrna.rna;
		// Set the 'stratagene' flag
		rna.stratagene = Reggie.isStratagene(rna.name);
		rna.external = Reggie.isExternal(rna.name);
		
		// Set the 'QC' flag 
		rna.qc = mrna.UseForQC;
		
		if (stratageneConc > 0)
		{
			if (rna.stratagene && !rna.NDConc) rna.NDConc = stratageneConc;
		}
		
		// Calculate volume to use and water to add based on concentration
		var remarks = [];
		if (rna.NDConc && rna.usedQuantity)
		{
			rna.volume = Math.ceil(10000*rna.usedQuantity/rna.NDConc) / 10; // µl
			if (rna.preNormalized)
			{
				rna.water = 0;
			}
			else
			{
				var totalVolume = mrna.DilutionConc ? 1000 * rna.usedQuantity / mrna.DilutionConc : 50;
				rna.water = totalVolume-rna.volume;
				if (totalVolume > 50)
				{
					remarks[remarks.length] = 'Large mix; Use 50µl';
				}
			}
		}
		
		// check for some issues that may indicate problems
		if (rna.qc) remarks[remarks.length] = 'QC';
		if (!rna.stratagene && !rna.external)
		{
			if (!rna.bioWell && !rna.preNormalized)
			{
				remarks[remarks.length] = 'No location';
			}
			if (!rna.remainingQuantity)
			{
				remarks[remarks.length] = 'No quantity';
			}
			else if (rna.remainingQuantity < rna.usedQuantity)
			{
				remarks[remarks.length] = 'Not enough RNA';
			}
			else if (rna.remainingQuantity < rna.usedQuantity * LOW_QUANTITY_WARNING_FACTOR && !rna.preNormalized)
			{
				remarks[remarks.length] = 'Low quantity';
			}
			if (!rna.NDConc)
			{
				remarks[remarks.length] = 'No NDConc value';
			}
		}
		else if (rna.stratagene)
		{
			if (!rna.NDConc && rna.usedQuantity) 
			{
				remarks[remarks.length] = 'Use ' + Numbers.formatNumber(rna.usedQuantity, 2) + ' µg RNA';
			}
		}
		else if (rna.external)
		{
			remarks[remarks.length] = 'Use ' + Numbers.formatNumber(rna.usedQuantity, 2) + ' µg RNA';
		}
		if (mrna.comment) remarks[remarks.length] = mrna.comment;
		rna.remarks = remarks;
	}

	protocol.viewAsPlate = function(plate, list)
	{
		var schema = PoolSchema.getById(plate.poolSchema);
		Plate.init(plate.rows, plate.columns, schema, WellPainter);
		
		for (var i = 0; i < list.length; i++)
		{
			var mrna = list[i];
			var well = mrna.bioWell;
			Plate.getWell(well.row, well.column).setExtract(mrna);
		}

		Plate.paint(Plate.getWells());
		PoolSchema.buildPoolTableRow(schema, plate.columns);
		Doc.show('all-protocol');
	}

	protocol.viewAsList = function(list)
	{
		for (var i = 0; i < list.length; i++)
		{
			var mrna = list[i];
			var rna = mrna.rna;
			var idSuffix = mrna.bioWell.column + '.' + mrna.bioWell.row;
			var tableRow = Doc.element('row.'+idSuffix);
			
			Doc.removeClass(tableRow, 'empty');
			if (rna.external) Doc.addClass(tableRow, 'external');
			if (rna.stratagene) Doc.addClass(tableRow, 'stratagene');
			Doc.element('rna.'+idSuffix).innerHTML = Strings.encodeTags(rna.external && mrna.externalId ? mrna.externalId : rna.name);
			Doc.element('box.'+idSuffix).innerHTML = Strings.encodeTags(protocol.getPlateCoordinate(rna, true));
			Doc.element('ndconc.'+idSuffix).innerHTML = Numbers.formatNumber(rna.NDConc, 2);
			Doc.element('remain.'+idSuffix).innerHTML = Numbers.formatNumber(rna.remainingQuantity, 2);
			Doc.element('volume.'+idSuffix).innerHTML = Numbers.formatNumber(rna.volume, 1);
			Doc.element('water.'+idSuffix).innerHTML = rna.preNormalized ? '—' : Numbers.formatNumber(rna.water, 1);
			Doc.element('remarks.'+idSuffix).innerHTML = rna.remarks.join('; ');
		}
		
		Doc.show('all-protocol');
	}
	
	
	protocol.getPlateCoordinate = function(rna, includePlateName)
	{
		var c = '';
		if (rna.bioWell)
		{
			if (includePlateName) c += rna.bioWell.bioPlate.name;
			c += ' ' + Reggie.wellToAlpha(rna.bioWell.row) + (rna.bioWell.column+1);
		}
		else if (rna.preNormalized)
		{
			c = 'PreNorm.';
		}
		else
		{
			c = ' ';
		}
		return c;
	}

		
	return protocol;
}();

Doc.onLoad(Protocol.initPage);


var WellPainter = function()
{
	var painter = {};
	
	painter.getClassNameForWell = function(well)
	{
		var cls = '';
		var mrna = well.extract;
		if (mrna)
		{
			var rna = mrna.rna;
			if (rna.qc) cls += ' qc';
			if (rna.external) cls += ' external';
			if (rna.stratagene) cls += ' stratagene';
		}
		return cls;
	}
	
	painter.getWellText = function(well)
	{
		var text = '';
		var mrna = well.extract;
		if (mrna)
		{
			var rna = mrna.rna;
			var name = rna.external && mrna.externalId ? mrna.externalId : rna.name;
			text += '<div class="rna">'+name+'</div>';
			text += '<div class="box">'+Strings.encodeTags(Protocol.getPlateCoordinate(rna, true))+'</div>';
			text += '<div class="remain">'+Numbers.formatNumber(rna.remainingQuantity, 2, 'µg')+'</div>';
			text += '<div class="ndconc">'+Numbers.formatNumber(rna.NDConc, 2, 'ng/µl') + '</div>';

			if (rna.volume >= 0 && rna.water >= 0)
			{
				text += '<div><span class="volume">'+Numbers.formatNumber(rna.volume, 1)+'µl</span>';
				text += '<span class="water">'+(rna.preNormalized ? '—' : Numbers.formatNumber(rna.water, 1)+'µl')+'</span></div>';
			}
			text += '<div class="remarks">'+ rna.remarks.join('; ') + '</div>';
		}
		return text;
	}

	return painter;
}();

